@@ -11,7 +11,7 @@
 #' Will accept any \code{data.frame} that can
 #' be converted to \code{data.table}.
 #'
-#' @inheritParams ex_data_table
+#' @inheritParams ex_data_table_step
 #'
 #' @examples
 #'
@@ -21,17 +21,17 @@
 #'     1L , "a" |
 #'     3L , "c" )
 #' rquery_pipeline <- local_td(dL)
-#' ex_data_table(rquery_pipeline)
+#' ex_data_table_step(rquery_pipeline)
 #'
 #' @export
-ex_data_table.relop_table_source <- function(optree,
+ex_data_table_step.relop_table_source <- function(optree,
                                              ...,
                                              tables = list(),
                                              source_usage = NULL,
                                              source_limit = NULL,
                                              env = parent.frame()) {
   force(env)
-  wrapr::stop_if_dot_args(substitute(list(...)), "rqdatatable::ex_data_table.relop_table_source")
+  wrapr::stop_if_dot_args(substitute(list(...)), "rqdatatable::ex_data_table_step.relop_table_source")
   name <- optree$table_name
   res <- NULL
   if(name %in% names(tables)) {
@@ -40,11 +40,11 @@ ex_data_table.relop_table_source <- function(optree,
     res <- get(name, envir = env)
   }
   if(is.null(res)) {
-    stop(paste("rqdatatable::ex_data_table.relop_table_source, could not find: ",
+    stop(paste("rqdatatable::ex_data_table_step.relop_table_source, could not find: ",
                name))
   }
   if(!is.data.frame(res)) {
-    stop(paste("rqdatatable::ex_data_table.relop_table_source ",
+    stop(paste("rqdatatable::ex_data_table_step.relop_table_source ",
                name,
                " is not a data.frame (class: ",
                paste(class(res), collapse = ", "),
@@ -59,7 +59,7 @@ ex_data_table.relop_table_source <- function(optree,
   }
   missing_cols <- setdiff(cols_want, cols_have)
   if(length(missing_cols)>0) {
-    stop(paste("rqdatatable::ex_data_table.relop_table_source missing required columns",
+    stop(paste("rqdatatable::ex_data_table_step.relop_table_source missing required columns",
                paste(missing_cols, collapse = ", ")))
   }
   if(!data.table::is.data.table(res)) {
