@@ -16,16 +16,16 @@ test_relop_natural_join <- function() {
  optree <- natural_join(local_td(d1), local_td(d2),
                         jointype = "FULL", by = 'key')
  res1 <- ex_data_table(optree)
- RUnit::checkTrue(data.table::is.data.table(res1))
+ RUnit::checkTrue(is.data.frame(res1))
 
  # full cross-product join
  # (usually with jointype = "FULL", but "LEFT" is more
  # compatible with rquery field merg semantics).
  optree2 <- natural_join(local_td(d1), local_td(d2),
                          jointype = "LEFT", by = NULL)
- res2 <- ex_data_table(optree2)[]
+ res2 <- ex_data_table(optree2)
  # notice ALL non-"by" fields take coalese to left table.
- RUnit::checkTrue(data.table::is.data.table(res2))
+ RUnit::checkTrue(is.data.frame(res2))
 
  invisible(NULL)
 }
